pymediainfo
-----------

.. image:: https://img.shields.io/pypi/v/pymediainfo.svg
  :target: https://pypi.org/project/pymediainfo

.. image:: https://img.shields.io/pypi/pyversions/pymediainfo.svg
  :target: https://pypi.org/project/pymediainfo

.. image:: https://api.travis-ci.org/sbraz/pymediainfo.svg?branch=master
  :target: https://travis-ci.org/sbraz/pymediainfo


This small package is a wrapper around the MediaInfo library. It works on
Linux, Mac OS X and Windows.

See https://pymediainfo.readthedocs.io/ for more information.
